==> gbsite-1.1.1.tar.gz: gbsite/templates/gborg/gborg_navpage.php <==
<? if(empty($top_bottom_nav_area) || $top_bottom_nav_area == "head") { ?>
<!--- ***
FILENAME:		gborg_navpage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	this file is included by *.php application files (the filename in
				the url) and is the complete navigation for greatbridge.org that
				dynamicly handles:
				- meta data
				- navigation display
				- inclusion of content templates
*** --->
<style>
a.leftNav:link	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_2 ?>;
  text-decoration:none;
}
a.leftNav:visited	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_2 ?>;
  text-decoration:none;
}
a.projNav	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_6 ?>;
  text-decoration:none;
}
a.adminNav	{
	font-family:"arial","verdana";
	font-size:12px;
	font-style:normal;
	color:<?= $color_3 ?>;
	text-decoration:underline;
}
.bg TD {
	background : url(<?= $image_path ?>/right_cell_bg.gif) no-repeat;
	background-color:<?= $color_5 ?>;

}
</style>
<html>
<head>
<meta name="keywords" description="<?= $meta_keyword ?>">
<meta name="description" description="<?= $meta_description ?>">
<title><?= $page_title ?></title>
</head>
<body bgcolor="<?= $color_2 ?>" leftmargin="0" topmargin="0" marginwidth="0" marginheight="0" vlink="<?= $color_6 ?>" alink="<?= $color_6 ?>" link="<?= $color_6 ?>">
<!-- the top table - hash marks - date - image links -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td bgcolor="<?= $color_2 ?>"><img src="<?= $image_path ?>/top_left.gif" width="59" height="24"></td>
<td bgcolor="<?= $color_2 ?>" width="100%" align="right"><img src="<?= $image_path ?>/top_right.gif" width="339" height="15"></td>
</tr>
<tr>
<td bgcolor="<?= $color_4 ?>"><img src="<?= $image_path ?>/top_logo_top.gif" width="200" height="35"></td>
<td bgcolor="<?= $color_4 ?>" background="<?= $image_path ?>/top_hash1.gif" width="100%" align="right"><font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b><? print (date ("F d, Y")); ?></b></font><img src="<?= $image_path ?>/shim.gif" width="10" height="17"></td>
</tr>
<tr>
<td bgcolor="<?= $color_4 ?>"><img src="<?= $image_path ?>/top_logo_mid.gif" width="200" height="6"></td>
<td bgcolor="<?= $color_4 ?>" background="<?= $image_path ?>/top_hash2.gif" width="100%"><img src="<?= $image_path ?>/shim.gif" width="1" height="6"></td>
</tr>
<tr>
<td bgcolor="<?= $color_5 ?>"><img src="<?= $image_path ?>/top_logo_bottom.gif" width="200" height="23"></td>
<td bgcolor="<?= $color_5 ?>" width="100%" align="right"><? if(!empty($member_id)) { ?><a href="/member/memlogout.php"><img src="<?= $image_path ?>/toplink_logout.gif" width="61" height="17" border="0"></a><? } else { ?><a href="/member/memjoin.php"><img src="<?= $image_path ?>/toplink_signup.gif" width="58" height="17" border="0"></a><a href="/member/memlogin.php"><img src="<?= $image_path ?>/toplink_login.gif" width="50" height="17" border="0"></a><? } ?><a href="/member/memmain.php"><img src="<?= $image_path ?>/toplink_my.gif" width="82" height="17" border="0"></a><img src="<?= $image_path ?>/shim.gif" width="10" height="17"></td>
</tr>
</table>
<!-- end top -->
<!-- left nav - content - right -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td valign="top" bgcolor="<?= $color_5 ?>">
	<table cellpadding="0" cellspacing="0" border="0" width="100%" class="bg">
	<tr>
	<td valign="top" bgcolor="<?= $color_5 ?>" height="390">
	<? if(!empty($member_id)) { ?>
	<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memlogout.php"><b>Log Out</b></a><br>
		<? 
		}
		else { ?>
		<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memjoin.php"><b>Sign Up</b></a><br>
		<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memlogin.php"><b>Log In</b></a><br>
	<? } ?>	
	<br>
	<!-- *** dynamicly generated navigation links *** -->
	<?

    function traverse_tree($t_nav_tree, $indent_code) {
        if(is_array($t_nav_tree)) {
            $child_indent = ($indent_code!=""?"<img src=\"${GLOBALS["image_path"]}/sub_level_off.gif\" width=\"12\" height=\"10\">":"<img src=\"${GLOBALS["image_path"]}/top_level_bullet.gif\" width=\"16\" height=\"10\">");
            while(list(,$branch) = @each($t_nav_tree)) {
				$sbold = ($branch["web_page"]==$GLOBALS["web_page"]?"<b><u>":"");
				$ebold = ($branch["web_page"]==$GLOBALS["web_page"]?"</u></b>":"");
			?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="<?= $branch["page_url"] ?>"><?= $sbold . $branch["link_name"] . $ebold ?></a><br><img src="<?= $GLOBALS["image_path"] ?>/shim.gif" width="1" height="3"><br>
			<?
			traverse_tree($branch["children"], "<img src=" .  $GLOBALS["image_path"] . "/shim.gif width=\"10\" height=\"1\">" . $indent_code);
            }
        }
    }
	traverse_tree($nav_tree, "");
 	?>
	<!-- *** end dynamicly generated navigation links *** -->
	<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="http://www.greatbridge.com/">GreatBridge.com</a><br>
	<!-- <br><br><br><img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/view_source.php?source=/usr/local/gbsite/htdocs/newsindex.php">View Source</a><br> -->
	<!-- *** bully the nav a bit *** --->
	</td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="118" height="1"></td>
	</tr>
	</table>
</td>
<!-- content -->
<td width="100%" valign="top" bgcolor="<?= $color_1 ?>">
	<table cellpadding="0" cellspacing="2" border="0" width="100%">
	<tr>
	<td>
		<table cellpadding="0" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_2 ?>">
		<tr>
		<td nowrap valign="top">
		<img src="<?= $image_path ?>/shim.gif" width="1" height="1">
		<? if(!empty($member_id)) { ?>
		<font face="<?= $font_1 ?>" color="<?= $color_5 ?>" size="2">Logged in as <b><?= $member_name ?></b></font>
		<? } ?>
		</td>
		<td align="right"><img src="<?= $image_path ?>/group_<?= $group_group_id ?>.gif" height="33"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="33"></td>
		</tr>
		<!-- if proj id not empty display proj nav -->
		<? if (!empty($project_id)) { ?>
		<tr bgcolor="<?= $color_1 ?>">
		<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<tr bgcolor="<?= $color_7 ?>">
		<td nowrap><img src="<?= $image_path ?>/shim.gif" width="1" height="1"><?  if($access_level == 4) { ?><b><a class="adminNav" href="/project/<?= $project_name ?>/projadmin.php">Project Admin Area</a></b><? } ?></td>
		<td align="right" width="100%" nowrap><b><a class="projNav" href="/project/<?= $project_name ?>/projdisplay.php"><?= $project_name ?> Home</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/bugs/buglist.php">Bugs</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/task/tasklist.php">Tasks</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/viewcvs/">CVS</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/patch/patchlist.php">Patches</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/download/download.php">Downloads</a>&nbsp;|&nbsp;<a class="projNav" href="http://www.greatbridge.org/mailman/listinfo/<?= $project_name ?>">Mailing Lists</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/errata.php">Errata</a></b></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<tr bgcolor="<?= $color_1 ?>">
		<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<? } ?>
		<tr>
		<td colspan="2" valign="top">
			<!--- *** include page template *** --->
			<?
			if(!empty($top_bottom_nav_area)){ ?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			<tr>
			<td><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
			</tr>
			<tr>
			<td>
			<? }
} # end the top nav include
if(empty($top_bottom_nav_area)) {
	include($template_path . "/" . $name_prefix . "_" . $web_page . ".php");
}
if(empty($top_bottom_nav_area) || $top_bottom_nav_area == "foot") {
			if(!empty($top_bottom_nav_area)){ ?>
			</td>
			</tr>
			</table>
			<? } ?>
			<!--- *** end page template include *** --->
		</td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="357"></td>
		</tr>
		</table>
	</td>
	</tr>
	</table>
</td>
<!-- right spacing - right nav potential -->
<td valign="top" bgcolor="<?= $color_5 ?>">
<img src="<?= $image_path ?>/shim.gif" width="10" height="1">
</td>
</tr>
</table>
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td bgcolor="<?= $color_5 ?>"><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<tr>
<td width="100%" bgcolor="<?= $color_1 ?>">.</td>
</tr>
</table>
</body>
</html>
<? }  #end the foot section ?>

==> gbsite-2.0.0.tar.gz: gbsite/templates/gborg/gborg_navpage.php <==
<? if(empty($top_bottom_nav_area) || $top_bottom_nav_area == "head") { ?>
<!--- ***
FILENAME:		gborg_navpage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	this file is included by *.php application files (the filename in
				the url) and is the complete navigation for greatbridge.org that
				dynamicly handles:
				- meta data
				- navigation display
				- inclusion of content templates
*** --->
<style>
a.leftNav:link	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_2 ?>;
  text-decoration:none;
}
a.leftNav:visited	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_2 ?>;
  text-decoration:none;
}
a.projNav	{
  font-family:"arial","verdana";
  font-size:12px;
  font-style:normal;
  color:<?= $color_6 ?>;
  text-decoration:none;
}
a.adminNav	{
	font-family:"arial","verdana";
	font-size:12px;
	font-style:normal;
	color:<?= $color_3 ?>;
	text-decoration:underline;
}
.bg TD {
	background : url(<?= $image_path ?>/right_cell_bg.gif) no-repeat;
	background-color:<?= $color_5 ?>;

}
</style>
<html>
<head>
<meta name="keywords" content="<?= $meta_keyword ?>">
<meta name="description" content="<?= $meta_description ?>">
<title><?= $page_title ?></title>
</head>
<body bgcolor="<?= $color_5 ?>" leftmargin="0" topmargin="0" marginwidth="0" marginheight="0" vlink="<?= $color_6 ?>" alink="<?= $color_6 ?>" link="<?= $color_6 ?>">
<!-- the top table - hash marks - date - image links -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td bgcolor="<?= $color_2 ?>"><img src="<?= $image_path ?>/top_left.gif" width="59" height="24"></td>
<td bgcolor="<?= $color_2 ?>" width="100%" align="right"><img src="<?= $image_path ?>/top_right.gif" width="339" height="15"></td>
</tr>
<tr>
<td bgcolor="<?= $color_4 ?>"><img src="<?= $image_path ?>/top_logo_top.gif" width="200" height="35"></td>
<td bgcolor="<?= $color_4 ?>" background="<?= $image_path ?>/top_hash1.gif" width="100%" align="right"><font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b><? print (date ("F d, Y")); ?></b></font><img src="<?= $image_path ?>/shim.gif" width="10" height="17"></td>
</tr>
<tr>
<td bgcolor="<?= $color_4 ?>"><img src="<?= $image_path ?>/top_logo_mid.gif" width="200" height="6"></td>
<td bgcolor="<?= $color_4 ?>" background="<?= $image_path ?>/top_hash2.gif" width="100%"><img src="<?= $image_path ?>/shim.gif" width="1" height="6"></td>
</tr>
<tr>
<td bgcolor="<?= $color_5 ?>"><img src="<?= $image_path ?>/top_logo_bottom.gif" width="200" height="23"></td>
<td bgcolor="<?= $color_5 ?>" width="100%" align="right"><? if(!empty($member_id)) { ?><a href="/member/memlogout.php"><img src="<?= $image_path ?>/toplink_logout.gif" width="61" height="17" border="0"></a><? } else { ?><a href="/member/memjoin.php"><img src="<?= $image_path ?>/toplink_signup.gif" width="58" height="17" border="0"></a><a href="/member/memlogin.php"><img src="<?= $image_path ?>/toplink_login.gif" width="50" height="17" border="0"></a><? } ?><a href="/member/memmain.php"><img src="<?= $image_path ?>/toplink_my.gif" width="82" height="17" border="0"></a><img src="<?= $image_path ?>/shim.gif" width="10" height="17"></td>
</tr>
</table>
<!-- end top -->
<!-- left nav - content - right -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td valign="top" bgcolor="<?= $color_5 ?>">
	<table cellpadding="0" cellspacing="0" border="0" width="100%" class="bg">
	<tr>
	<td valign="top" bgcolor="<?= $color_5 ?>" height="390">
	<? if(!empty($member_id)) { ?>
	<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memlogout.php"><b>Log Out</b></a><br>
		<? 
		}
		else { ?>
		<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memjoin.php"><b>Sign Up</b></a><br>
		<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/member/memlogin.php"><b>Log In</b></a><br>
	<? } ?>	
	<br>
	<!-- *** dynamicly generated navigation links *** -->
	<?

    function traverse_tree($t_nav_tree, $indent_code) {
        if(is_array($t_nav_tree)) {
            $child_indent = ($indent_code!=""?"<img src=\"${GLOBALS["image_path"]}/sub_level_off.gif\" width=\"12\" height=\"10\">":"<img src=\"${GLOBALS["image_path"]}/top_level_bullet.gif\" width=\"16\" height=\"10\">");
            while(list(,$branch) = @each($t_nav_tree)) {
				$sbold = ($branch["web_page"]==$GLOBALS["web_page"]?"<b><u>":"");
				$ebold = ($branch["web_page"]==$GLOBALS["web_page"]?"</u></b>":"");
			?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="<?= $branch["page_url"] ?>"><?= $sbold . $branch["link_name"] . $ebold ?></a><br><img src="<?= $GLOBALS["image_path"] ?>/shim.gif" width="1" height="3"><br>
			<?
			traverse_tree($branch["children"], "<img src=" .  $GLOBALS["image_path"] . "/shim.gif width=\"10\" height=\"1\">" . $indent_code);
            }
        }
    }
	traverse_tree($nav_tree, "");
 	?>
	<!-- *** end dynamicly generated navigation links *** -->
	<img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="http://www.greatbridge.com/">GreatBridge.com</a><br>
	<img src="<?= $image_path ?>/shim.gif" width="118" height="1">
	<!-- <br><br><br><img src="<?= $image_path ?>/top_level_bullet.gif" width="16" height="10"><a class="leftNav" href="/view_source.php?source=/usr/local/gbsite/htdocs/newsindex.php">View Source</a><br> -->
	<!-- *** bully the nav a bit *** --->
	</td>
	</tr>
	</table>
</td>
<!-- content -->
<td width="100%" valign="top" bgcolor="<?= $color_1 ?>">
	<table cellpadding="0" cellspacing="2" border="0" width="100%">
	<tr>
	<td>
		<table cellpadding="0" cellspacing="0" border="0" width="100%" bgcolor="<?= $color_2 ?>">
		<tr>
		<td nowrap valign="top">
		<img src="<?= $image_path ?>/shim.gif" width="1" height="1">
		<? if(!empty($member_id)) { ?>
		<font face="<?= $font_1 ?>" color="<?= $color_5 ?>" size="2">Logged in as <b><?= $member_name ?></b></font>
		<? } ?>
		</td>
		<td align="right"><img src="<?= $image_path ?>/group_<?= $group_group_id ?>.gif" height="33"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="33"></td>
		</tr>
		<!-- if proj id not empty display proj nav -->
		<? if (!empty($project_id)) { ?>
		<tr bgcolor="<?= $color_1 ?>">
		<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<tr bgcolor="<?= $color_7 ?>">
		<td nowrap><img src="<?= $image_path ?>/shim.gif" width="1" height="1"><?  if($access_level == 4) { ?><b><a class="adminNav" href="/project/<?= $project_name ?>/projadmin.php">Project Admin Area</a></b><? } ?></td>
		<td align="right" width="100%" nowrap><b><a class="projNav" href="/project/<?= $project_name ?>/projdisplay.php"><?= $project_name ?> Home</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/bugs/buglist.php">Bugs</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/task/tasklist.php">Tasks</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/viewcvs/">CVS</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/patch/patchlist.php">Patches</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/download/download.php">Downloads</a>&nbsp;|&nbsp;<a class="projNav" href="http://www.greatbridge.org/mailman/listinfo/<?= $project_name ?>">Mailing Lists</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/errata.php">Errata</a>&nbsp;|&nbsp;<a class="projNav" href="/project/<?= $project_name ?>/faq/">Faq</a></b></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<tr bgcolor="<?= $color_1 ?>">
		<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
		</tr>
		<? } ?>
		<tr>
		<td colspan="2" valign="top">
			<!--- *** include page template *** --->
			<?
			if(!empty($top_bottom_nav_area)){ ?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
			<tr>
			<td><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
			</tr>
			<tr>
			<td>
			<? }
} # end the top nav include
if(empty($top_bottom_nav_area)) {
	include($template_path . "/" . $name_prefix . "_" . $web_page . ".php");
}
if(empty($top_bottom_nav_area) || $top_bottom_nav_area == "foot") {
			if(!empty($top_bottom_nav_area)){ ?>
			</td>
			</tr>
			</table>
			<? } ?>
			<!--- *** end page template include *** --->
		</td>
		<td><img src="<?= $image_path ?>/shim.gif" width="1" height="357"></td>
		</tr>
		</table>
	</td>
	</tr>
	</table>
</td>
<!-- right spacing - right nav potential -->
<td valign="top" bgcolor="<?= $color_5 ?>">
<img src="<?= $image_path ?>/shim.gif" width="10" height="1">
</td>
</tr>
</table>
<!-- footer -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td bgcolor="<?= $color_5 ?>"><img src="<?= $image_path ?>/shim.gif" width="1" height="10"></td>
</tr>
<tr>
<td align="center">
<a href="http://www.greatbridge.com/"><img src="<?= $image_path ?>/powered_by.gif" width="100" height="40" border="0"></a><br>
<font face="<?= $font_1 ?>" size="1" color="<?= $color_2 ?>">Content owned by Great Bridge is copyright  2000-2001 Great Bridge, LLC. All rights reserved.</font>
</td>
</tr>
</table>
</body>
</html>
<? }  #end the foot section ?>
